# -*- coding: utf-8 -*-

"""
Smashtheque API Wrapper
~~~~~~~~~~~~~~~~~~~
A basic wrapper for the Smashtheque API.
:copyright: (c) 2021-present Retropen-Bar
:license: MIT, see LICENSE for more details.
"""

__title__ = 'smashtheque'
__author__ = 'Retropen-Bar'
__license__ = 'MIT'
__copyright__ = 'Copyright 2021-present Retropen-Bar'
__version__ = '0.0.1'
